@@ -24,26 +24,30 @@ namespace EventTypes { class iEvent; }
 
 class NumberToNameLookup;
 class Settings;
-template <typename T1> class QList;
+#include <QList>
+template <typename T1> class QSharedPointer;
+
+#include "iDBBackend.h"
 
 namespace DBBackends
 {
-	class iDBBackend;
-
 	class AllBackends
 	{
 	public:
 		AllBackends(const Settings &settings);
 
-		const QList<iDBBackend *> & Backends() const;
 		void Process(EventProcessors::iEventProcessor &eventProcessor);
+		void PreInsert();
 		void Insert(EventTypes::iEvent &event, const NumberToNameLookup &numberToNameLookup);
+		void PostInsert();
 
 	public:
 		const Settings &CurrentSettings() const { return m_Settings; }
+		const QList<QSharedPointer<iDBBackend> > &Backends() const { return m_Backends; }
 
 	private:
 		const Settings &m_Settings;
+		const QList<QSharedPointer<iDBBackend> > m_Backends;
 	};
 }
 
