@@ -25,22 +25,36 @@ Fmms::Fmms(const Settings &settings) :
 {
 }
 
-Fmms::Fmms(const Settings &settings, const EventTypes::FmmsEvent &event) :
+Fmms::Fmms(const Settings &settings, const EventTypes::FmmsEvent &/*event*/) :
 	m_Settings(settings)
 {
 }
 
-void Fmms::Process(EventProcessors::iEventProcessor &eventProcessor)
+void Fmms::Process(EventProcessors::iEventProcessor &/*eventProcessor*/)
 {
 
 }
 
-EventTypes::iEvent *const Fmms::CreateEvent(int &fevent, QList<void *> &fattachments)
+EventTypes::iEvent *const Fmms::CreateEvent(int &/*fevent*/, QList<void *> &/*fattachments*/)
 {
 	return 0;
 }
 
-void Fmms::Insert(EventTypes::iEvent &event, const NumberToNameLookup &numberToNameLookup)
+void Fmms::PreInsert()
+{
+}
+
+void Fmms::Insert(EventTypes::iEvent &/*event*/, const NumberToNameLookup &/*numberToNameLookup*/)
 {
 	return;
 }
+
+void Fmms::PostInsert()
+{
+}
+
+void Fmms::ClearInsertedIDs()
+{
+	InsertedIDs().clear();
+}
+
