@@ -23,15 +23,27 @@ namespace EventProcessors { class iEventProcessor; }
 namespace EventTypes { class RtcomEvent; class iEvent; }
 class NumberToNameLookup;
 
+template <typename T1> class QList;
+
 namespace DBBackends
 {
 	class iDBBackend
 	{
 	public:
+		virtual ~iDBBackend() {}
+
+		virtual void PreInsert() =0;
 		virtual void Insert(EventTypes::iEvent &event, const NumberToNameLookup &numberToNameLookup) =0;
+		virtual void PostInsert() =0;
+
+		virtual void ClearInsertedIDs() =0;
 		//virtual uint Remove();
 
 		virtual void Process(EventProcessors::iEventProcessor &eventProcessor) =0;
+
+	protected:
+		virtual const QList<unsigned int> &InsertedIDs() const =0;
+
 	};
 }
 
