@@ -19,24 +19,43 @@
 #ifndef EVENTPARSERS_CSVSYMBIANEVENTLOGPARSER_H
 #define EVENTPARSERS_CSVSYMBIANEVENTLOGPARSER_H
 
+#include "EventFormats/SymbianEventLog.h"
 #include "iEventParser.h"
+#include "Settings.h"
 
-template <typename T1, typename T2> class QHash;
+#include <QHash>
+class QChar;
 class QFile;
 class QString;
+class QStringList;
 
 namespace EventParsers
 {
-	class CSVSymbianEventLogParser : public iEventParser
+	class CSVSymbianEventLogParser : public iEventParser, public SymbianEventLog
 	{
 	public:
 		typedef QHash<QString, int> ColumnIndicesHash;
 
-		static iEventParser *IsValid(QFile &eventFile);
+		static iEventParser *IsValid(const Settings &currentSettings, QFile &eventFile);
 
-		CSVSymbianEventLogParser(const QString &filename, const ColumnIndicesHash &columns);
+		CSVSymbianEventLogParser(const Settings &currentSettings, const QString &filename);
 
 		virtual EventTypes::EventFromFileList ParseFile(QFile &eventFile, const QList<unsigned int> &recordsToReturn);
+
+	private:
+		Settings::eDirection ReadDirection(const uint value);
+
+	protected:
+		const Settings &CurrentSettings() const { return m_Settings; }
+		const StringsLookup &Strings() const { return m_Strings; }
+		StringsLookup &Strings() { return m_Strings; }
+
+	protected:
+		void Strings(const StringsLookup &strings) { m_Strings = strings; }
+
+	private:
+		const Settings &m_Settings;
+		StringsLookup m_Strings;
 	};
 }
 
