@@ -19,6 +19,8 @@
 #ifndef EVENTPARSERS_VMGEntities_FACTORY_H
 #define EVENTPARSERS_VMGEntities_FACTORY_H
 
+class Settings;
+
 class QString;
 
 namespace EventParsers
@@ -34,7 +36,7 @@ namespace EventParsers
 			Factory() {};
 
 		public:
-			static iReader* Instantiate(QString& lineData, const SMSEntity* parent);
+			static iReader* Instantiate(const Settings &settings, QString& lineData, const SMSEntity* parent);
 		};
 	}
 }
