@@ -22,8 +22,8 @@
 
 using namespace EventParsers::VMGEntities;
 
-SMSEntity::SMSEntity(const SMSEntity* parent):
-	m_Parent(parent)
+SMSEntity::SMSEntity(const Settings &settings, const SMSEntity *parent):
+	m_Settings(settings), m_Parent(parent)
 {
 }
 
