@@ -19,6 +19,8 @@
 #ifndef EVENTPARSERS_VMGEntities_SMSENTITY_H
 #define EVENTPARSERS_VMGEntities_SMSENTITY_H
 
+class Settings;
+
 #include <cstddef>
 #include <typeinfo>
 
@@ -31,16 +33,20 @@ namespace EventParsers
 		class SMSEntity
 		{
 		public:
-			SMSEntity(const SMSEntity* parent);
-			virtual ~SMSEntity() {};
+			SMSEntity(const Settings &settings, const SMSEntity* parent);
+			virtual ~SMSEntity() {}
 
 		protected:
 			const bool isAttachment() const;
 
-			const SMSEntity* m_Parent;
-			const SMSEntity* getParent() const { return m_Parent; };
+			const SMSEntity *getParent() const { return m_Parent; }
 
-			virtual const char* getTagName() const { return "VBODY"; }
+			virtual const char *getTagName() const { return "VBODY"; }
+			const Settings &CurrentSettings() const { return m_Settings; }
+
+		private:
+			const Settings &m_Settings;
+			const SMSEntity *m_Parent;
 		};
 	}
 }
