@@ -28,22 +28,22 @@
 
 using namespace EventParsers::VMGEntities;
 
-iReader *Factory::Instantiate(QString& lineData, const SMSEntity *parent)
+iReader *Factory::Instantiate(const Settings &settings, QString& lineData, const SMSEntity *parent)
 {
 	if(lineData.startsWith("BEGIN:"))
 	{
 		QString item = lineData.mid(lineData.indexOf(":")+1);
 
 		if(item == "VMSG")
-			return new VMessage(parent);
+			return new VMessage(settings, parent);
 		else if(item == "VCARD")
-			return new VCard(parent);
+			return new VCard(settings, parent);
 		else if(item == "VENV")
-			return new VEnvelope(parent);
+			return new VEnvelope(settings, parent);
 		else if(item == "VBODY")
-			return new VBody(parent);
+			return new VBody(settings, parent);
 		else if(item == "VCALENDAR")
-			return new VCalendar(parent);
+			return new VCalendar(settings, parent);
 	}
 
 	qDebug() << "Unrecognised entity '" << lineData <<"'";
