@@ -20,6 +20,7 @@
 #define EVENTPARSERS_VMGEntities_IWRITER_H
 
 namespace EventTypes { class SMS; }
+class NumberToNameLookup;
 
 class QTextStream;
 
@@ -31,7 +32,7 @@ namespace EventParsers
 		{
 		public:
 			virtual ~iWriter() {};
-			virtual void Write(QTextStream& stream, const EventTypes::SMS& event) = 0;
+			virtual void Write(QTextStream& stream, const EventTypes::SMS& event, const NumberToNameLookup &numberToNameLookup) = 0;
 		};
 	}
 }
