@@ -33,7 +33,7 @@ void Hasher::Process(EventTypes::iEvent &event)
 {
 	uint hash(event.HashCode());
 	m_Hashes.insert(hash);
-	qDebug() << "DB Event hash: " << hash << " @ " << event.Timestamp();
+	qDebug() << "DB Event hash: " << hash << " @ " << event.Timestamp().toUTC();
 }
 
 void Hasher::EmitEventProcessed(int eventsProcessed, int totalEvents)
