@@ -19,13 +19,33 @@
 #include "Writer.h"
 
 #include "EventTypes/iEvent.h"
+#include "EventWriters/iEventWriter.h"
+#include "EventWriters/CSVSymbianEventLogWriter.h"
+#include "EventWriters/VMGWriter.h"
 #include "Settings.h"
 
+#include <QDebug>
+
+#include <QList>
+#include <QSharedPointer>
+
 using namespace EventProcessors;
 
+Writer::Writer(Settings &settings, const NumberToNameLookup &numberToNamelookup)
+	: m_Settings(settings)
+{
+	m_Writers.append(QSharedPointer<EventWriters::iEventWriter>(new EventWriters::CSVSymbianEventLogWriter(CurrentSettings(), numberToNamelookup)));
+	m_Writers.append(QSharedPointer<EventWriters::iEventWriter>(new EventWriters::VMGWriter(CurrentSettings(), numberToNamelookup)));
+}
+
+Writer::~Writer()
+{
+}
+
 void Writer::Process(EventTypes::iEvent &event)
 {
-	event.Export(CurrentSettings().Directory());
+	foreach (QSharedPointer<EventWriters::iEventWriter> writer, m_Writers)
+		writer->Write(event);
 }
 
 void Writer::EmitEventProcessed(int eventsProcessed, int totalEvents)
