@@ -21,9 +21,13 @@
 
 #include "iEventProcessor.h"
 
+#include "EventWriters/iEventWriter.h"
+class NumberToNameLookup;
 class Settings;
 
 #include <QObject>
+template <typename T1> class QList;
+#include <QSharedPointer>
 
 namespace EventProcessors
 {
@@ -32,9 +36,8 @@ namespace EventProcessors
 		Q_OBJECT
 
 	public:
-		Writer(Settings &settings)
-			: m_Settings(settings)
-		{}
+		Writer(Settings &settings, const NumberToNameLookup &numberToNamelookup);
+		~Writer();
 
 		const Settings & CurrentSettings() { return m_Settings; }
 
@@ -43,6 +46,7 @@ namespace EventProcessors
 
 	private:
 		const Settings & m_Settings;
+		QList<QSharedPointer<EventWriters::iEventWriter> > m_Writers;
 
 	signals:
 		void EventProcessed(int current, int total);
