@@ -19,6 +19,7 @@
 #ifndef EVENTTYPES_EVENTFROMFILE_H
 #define EVENTTYPES_EVENTFROMFILE_H
 
+template <typename T1> class QSharedPointer;
 template <typename T1> class QList;
 template <typename T1, typename T2> class QPair;
 
@@ -26,7 +27,7 @@ namespace EventTypes
 {
 	class iEvent;
 
-	typedef QPair<iEvent *, unsigned int> EventFromFile;
+	typedef QPair<QSharedPointer<EventTypes::iEvent>, unsigned int> EventFromFile;
 }
 
 #endif // EVENTTYPES_EVENTFROMFILE_H
