@@ -22,6 +22,7 @@
 #include "iEvent.h"
 
 #include <QList> // Needed for default value
+class QString;
 
 class _RTComElAttachment;
 typedef _RTComElAttachment RTComElAttachment;
@@ -44,6 +45,8 @@ namespace EventTypes
 
 		virtual RTComElEvent * toRTComEvent(const NumberToNameLookup &numberToNameLookup) const = 0;
 		static void freeRTComContents(RTComElEvent &event);
+
+		const unsigned int GetFlagValue(const QString &value) const;
 	};
 }
 
