@@ -35,10 +35,6 @@ namespace EventTypes
 		public:
 			virtual ~iEvent() {}
 
-			virtual const DBBackends::iDBBackend &DB() const =0;
-
-			virtual void Export(const QString &baseDirectory) const =0;
-
 			virtual const QDateTime Timestamp() const =0;
 			virtual const AttachmentCollection & Attachments() const =0;
 			virtual AttachmentCollection & Attachments() =0;
